Skip to contents

Extracts the metadata from the new references found on Scopus based on the search string(s) saved in "search_list.txt".

Usage

extract_scp_list(search_list_path, directory)

Arguments

search_list_path

Path to "search_list.txt".

directory

Choose the directory in which the references identification history will be saved.

Value

A data.frame with one row per retrieved Scopus record and columns:

author

Character. Publication authors.

year

Character. Publication year.

title

Character. Publication title.

journal

Character. Publication journal name.

volume

Character. Publication journal volume.

issue

Character. Publication journal issue.

abstract

Character. Publication abstract.

doi

Character. Publication Digital Object Identifier (DOI).

source

Character. Data source.

platform_id

Character. Publication unique identifier in data source.

If search_list_path does not exist, returns NULL.